summaryrefslogtreecommitdiff
path: root/board/jupiter/jupiter.c
diff options
context:
space:
mode:
Diffstat (limited to 'board/jupiter/jupiter.c')
-rw-r--r--board/jupiter/jupiter.c10
1 files changed, 7 insertions, 3 deletions
diff --git a/board/jupiter/jupiter.c b/board/jupiter/jupiter.c
index d56902bcd2..ea24eaa5c0 100644
--- a/board/jupiter/jupiter.c
+++ b/board/jupiter/jupiter.c
@@ -29,6 +29,8 @@
#define SDRAM_CONFIG2 0x88b70004
#endif
+DECLARE_GLOBAL_DATA_PTR;
+
#ifndef CONFIG_SYS_RAMBOOT
static void sdram_start (int hi_addr)
{
@@ -71,12 +73,12 @@ static void sdram_start (int hi_addr)
#endif
/*
* ATTENTION: Although partially referenced initdram does NOT make real use
* use of CONFIG_SYS_SDRAM_BASE. The code does not work if CONFIG_SYS_SDRAM_BASE
* is something else than 0x00000000.
*/
-phys_size_t initdram (int board_type)
+int dram_init(void)
{
ulong dramsize = 0;
ulong dramsize2 = 0;
@@ -194,7 +196,9 @@ phys_size_t initdram (int board_type)
__asm__ volatile ("sync");
}
- return dramsize + dramsize2;
+ gd->ram_size = dramsize + dramsize2;
+
+ return 0;
}
int checkboard (void)
@@ -71,12 +73,12 @@ static void sdram_start (int hi_addr)
#endif
/*
- * ATTENTION: Although partially referenced initdram does NOT make real use
+ * ATTENTION: Although partially referenced dram_init does NOT make real use
* use of CONFIG_SYS_SDRAM_BASE. The code does not work if CONFIG_SYS_SDRAM_BASE
* is something else than 0x00000000.